#include <iomanip>
#include <iostream>
#include <vector>
#include <map>
#include <Random.h>
#include "FrameList.h"
#include "errstr.h"
#include "Xmm.h"
#include "SelectUtils.h"

#include <ctime>

Frames::Frames(double start, double stop, double fracExp) :
 _fracExp(fracExp)
{
  _gti = Gti(start,stop);
}

double Frames::getFracExp()
{
  return _fracExp;
}

Gti Frames::getGTI()
{
  return _gti;
}

FrameList::FrameList()
{
	randGen.reset();
	randGen.min(-1.0);
	randGen.max(1.0);
	errstr << "Seeting random generator between (-1.0,1.0) "
			<< Sas::message(Msg::Lib, Msg::Verbose);

}
FrameList::~FrameList()
{

	randGen.min(-0.5);
	randGen.max(0.5);
	errstr << "Seeting random generator back to  (-0.5,0.5) "
			<< Sas::message(Msg::Lib, Msg::Verbose);

}
void FrameList::printFrames()
{

	for (unsigned int n = 0 ; n < (*this)._frames.size() ; n++) {
		errstr << std::setprecision(19) << "FrameBin= [ "<< (*this)._frames[n].start() << " , "
			<< (*this)._frames[n].stop() << " ]   FRACEXP= "<< (*this)._frames[n].getFracExp()
			<< Sas::message(Msg::Lib, Msg::Verbose);
	}
}

void FrameList::printDeadTime()
{
	for (unsigned int n = 0 ; n < (*this)._frames.size()-1 ; n++)
		errstr << "DeadTimeBin[ "<< n << "]= "<<
			(*this)._frames[n+1].stop()-(*this)._frames[n].stop()
			<< Sas::message(Msg::Lib, Msg::Verbose);
}

void FrameList::setGTI(Gti gti)
{
  _frameList.push_back(gti);
}

void FrameList::setFrame(Frames frm)
{
  _frames.push_back(frm);
}


double FrameList::getRandomTime()
{
	unsigned int exposuEntries = (*this)._frames.size();
	// Default randomization goes from -0.5 to 0.5
	double val = exposuEntries * abs(randGen.rand());

	double time =(*this)._frames[val]._gti.start()  +
			( ( (*this)._frames[val]._gti.stop() - (*this)._frames[val]._gti.start() ) / 2.);

	return time;
}


