#ifndef LIGHTCURVE_H_
#define LIGHTCURVE_H_

#include <string>
#include <vector>
#include <map>

#include <Dal.h>
#include <DataSubspace.h>
#include "LCGrid.h"
#include "Spect.h"
#include "Exposure.h"

class LightCurve {

public:
	LightCurve(){};
	LightCurve(string timeSerie, string evtList);
	LightCurve(string bkgSerie);
	LightCurve(double val0, double val1, double binSize=1.0);
	~LightCurve();

	void doRelativeCorr(Spect::arfgenType val);
	void calSpec();
	Spect* getSpec();

	bool moreThanOneCCD();
	void substractBKGForAllCCDs(LightCurve *bkg);
	void doAbsoluteCorr();
	void doAbsoluteCorr2();
	void applyAbsCorr();
	LCGrid* getLC();

	void setTotalBackscale(int);
	int getTotalBackscale();

	void createGti(LightCurve *lc, string name, DataSet *set);
	void createFile(string outFileName, LightCurve *bkgLC);

	std::string _instrument;

	LightCurve* operator-(LightCurve* bkg);

	std::vector<Exposure> _expVector;
	std::vector<Spect*> _spectVector;
private:
	LCGrid* setLC(string timeSerie);
	void setDSS();
	void setEventList(string evtList);
	void createCCDsLC();
	void setCCDsInRegion();
	void doGTICorr(LCGrid* lc);
	void doExposureCorr(LCGrid* lc,double area);
	void doExpCorrMultpleCCDs(LCGrid *lc);
	void doCCDCorrection(Spect *sp,Spect::arfgenType val);

	void closeTimeSerie();
	void closeEventList();

	void mergeFrames();

	std::vector<std::string> searchFor(LCGrid *lc);


	LCGrid *_LC;
	Spect *_spec;
	std::string _evtListName;
	DataSet *_evtList;
	DataSet *_ts;
	std::vector<LCGrid*> _ccdLC;
	std::vector<int> _ccdInRegion;
	DataSubspace _dss;
	bool _tsExists;
	bool _evtExists;
	bool _bkgCorrected;
	std::string _telescope;
	std::string _filter;
	double _mjdref;
	std::string _timeSys;
	std::string _timeSysComment;
	std::string _timeUnit;
	std::string _timeRef;
	std::string _timeRefComment;
	std::string _timeAssign;
	std::string _timeAssignComment;
	std::string _timeClockApp;
	std::string _subMode;
	std::string _obs_id;
	std::string _exp_id;
	std::string _observer;
	std::string _object;
	std::string _exp_id_str;
	double _tstart;
	double _tstop;

	double _exposure;

};




#endif /*LIGHTCURVE_H_*/
